@@ -6,6 +6,7 @@ import time
 import json
 
 from pathlib import Path
+import importlib.resources
 from typing import Union, Any
 from loguru import logger
 from typing import Callable, Optional
@@ -98,7 +99,7 @@ class Plantsim:
         self,
         version: Union[PlantsimVersion, str] = PlantsimVersion.V_MJ_22_MI_1,
         visible: bool = True,
-        trusted: bool = True,
+        trusted: bool = False,
         license: Union[PlantsimLicense, str] = PlantsimLicense.VIEWER,
         suppress_3d: bool = False,
         show_msg_box: bool = False,
@@ -496,11 +497,9 @@ class Plantsim:
 
     def _load_simtalk_script(self, script_name: str) -> str:
         """Loads a SimTalk script"""
-        file_path: str = (
-            Path(__file__).parent / "sim_talk_scripts" / f"{script_name}.st"
-        )
-        txt = Path(file_path).read_text()
-        return txt
+        package = __package__
+        resource = f"sim_talk_scripts/{script_name}.st"
+        return importlib.resources.files(package).joinpath(resource).read_text()
 
     def install_error_handler(self, model_path: PlantsimPath):
         """Installs the Error handler in the model"""
@@ -618,6 +617,7 @@ class Plantsim:
         if self._simulation_error_event.is_set():
             if on_simulation_error:
                 on_simulation_error(self, self._simulation_error_event.error)
+                return
             raise self._simulation_error_event.error
 
         if on_endsim:
